==> cherokee-0.4.6-031013.tar.gz: cherokee-0.4.6/src/validator_pam.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2003 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE_VALIDATOR_PAM_H__
#define __CHEROKEE_VALIDATOR_PAM_H__

#include "validator.h"

typedef struct {
	   cherokee_validator_t validator;
	   
} cherokee_validator_pam_t;

#define PAM(x) ((cherokee_validator_pam_t *)(x))


ret_t cherokee_validator_pam_new   (cherokee_validator_pam_t **pam);
ret_t cherokee_validator_pam_init  (cherokee_validator_pam_t  *pam, const char *dir);
ret_t cherokee_validator_pam_free  (cherokee_validator_pam_t  *pam);
ret_t cherokee_validator_pam_check (cherokee_validator_pam_t  *pam, const char *login, const char *passwd);

#endif /* __CHEROKEE_VALIDATOR_PAM_H__ */

==> cherokee-0.4.6-20031231.tar.gz: cherokee-0.4.6/src/validator_pam.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE_VALIDATOR_PAM_H__
#define __CHEROKEE_VALIDATOR_PAM_H__

#include "validator.h"
#include "connection.h"

typedef struct {
	   cherokee_validator_t validator;
	   
} cherokee_validator_pam_t;

#define PAM(x) ((cherokee_validator_pam_t *)(x))


ret_t cherokee_validator_pam_new   (cherokee_validator_pam_t **pam, cherokee_table_t *properties);
ret_t cherokee_validator_pam_free  (cherokee_validator_pam_t  *pam);
ret_t cherokee_validator_pam_check (cherokee_validator_pam_t  *pam, cherokee_connection_t *conn);

#endif /* __CHEROKEE_VALIDATOR_PAM_H__ */
